# Installing the required packages for this analysis. 
# This is only required once. 
# Uncomment the code below to run the install.packages function.
# install.packages(c("eRm", "dplyr", "ggplot2", "pairwise", "TAM", "psych"))

# Load the packages required for the analysis
library(eRm)
library(dplyr)
library(pairwise)

# Reading in the comma-seperated data set
df <- read.csv("BLOT.csv", header = FALSE, sep = ";") 

# Defining the name of the first column of the data frame called "df"
colnames(df)[1] <- c("id") 
# Defining the names of the columns referring to the items
colnames(df)[2:49] <- paste("Blot", (1:48), sep="_") 
# Selecting only the BLOT items
blot_items <- dplyr::select(df, Blot_1:Blot_35) 

# Calculate Rasch item paramters using the "pairwise" package
pair_rasch_blot <- pair(blot_items)
# Obtain person parameters using the "pairwise" package functions
pers <- pers(pair_rasch_blot)
# Perform the PCA
rasch_pca <- rfa(pers)
plot(rasch_pca, com = 1)

summary(rasch_pca)

# This line estimates Q3 for each item and stores the results as an object
yen_q3 <- q3(pers) 
# Estimated Yen's Q3, rounded to 2 decimal spaces
round(yen_q3[["resid_cor"]][["cor"]],2)
